# 进度条



# todo：进度条待完善，用于所有的方法中

def progress():
    pass